Struct async_ringbuf::producer::AsyncProducer
source · pub struct AsyncProducer<T, R: RbRef>where
R::Rb: AsyncRbWrite<T>,{ /* private fields */ }Implementations
sourceimpl<T, R: RbRef> AsyncProducer<T, R>where
R::Rb: AsyncRbWrite<T>,
impl<T, R: RbRef> AsyncProducer<T, R>where R::Rb: AsyncRbWrite<T>,
pub fn from_base(base: Producer<T, R>) -> Self
pub fn as_base(&self) -> &Producer<T, R>
pub fn as_mut_base(&mut self) -> &mut Producer<T, R>
pub fn capacity(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn is_full(&self) -> bool
pub fn len(&self) -> usize
pub fn free_len(&self) -> usize
sourcepub fn push(&mut self, item: T) -> PushFuture<'_, T, R> ⓘ
pub fn push(&mut self, item: T) -> PushFuture<'_, T, R> ⓘ
Push item to the ring buffer waiting asynchronously if the buffer is full.
Future returns:
Ok- item successfully pushed.Err(item)- the corresponding consumer was dropped, item is returned back.
sourcepub fn push_iter<I: Iterator<Item = T>>(
&mut self,
iter: I
) -> PushIterFuture<'_, T, R, I> ⓘ
pub fn push_iter<I: Iterator<Item = T>>( &mut self, iter: I ) -> PushIterFuture<'_, T, R, I> ⓘ
Push items from iterator waiting asynchronously if the buffer is full.
Future returns:
Ok- iterator ended.Err(iter)- the corresponding consumer was dropped, remaining iterator is returned back.
sourcepub fn wait_free(&self, free_len: usize) -> WaitFreeFuture<'_, T, R> ⓘ
pub fn wait_free(&self, free_len: usize) -> WaitFreeFuture<'_, T, R> ⓘ
Wait for the buffer to have at least free_len free places for items or to close.
Panics if free_len is greater than buffer capacity.
sourceimpl<T: Copy, R: RbRef> AsyncProducer<T, R>where
R::Rb: AsyncRbWrite<T>,
impl<T: Copy, R: RbRef> AsyncProducer<T, R>where R::Rb: AsyncRbWrite<T>,
sourcepub fn push_slice<'a: 'b, 'b>(
&'a mut self,
slice: &'b [T]
) -> PushSliceFuture<'a, 'b, T, R> ⓘ
pub fn push_slice<'a: 'b, 'b>( &'a mut self, slice: &'b [T] ) -> PushSliceFuture<'a, 'b, T, R> ⓘ
Copy slice contents to the buffer waiting asynchronously if the buffer is full.
Future returns:
Ok- all slice contents are copied.Err(count)- the corresponding consumer was dropped, number of copied items returned.